@@ -13,6 +13,46 @@ from weaverbird.backends.sql_translator.types import (
 )
 from weaverbird.pipeline.steps import ConvertStep
 
+PG_BOOLEAN_VALUES = ','.join(
+    [
+        f'\'{el}\''
+        for el in ['t', 'true', 'y', 'yes', 'on', '1', 'f', 'false', 'n', 'no', 'off', '0']
+    ]
+)
+
+
+def build_psql(retrieved_col_type, data_type, col):
+    if retrieved_col_type == 'TEXT' and data_type == 'boolean':
+        return f'CASE WHEN {col} IN ({PG_BOOLEAN_VALUES}) THEN CAST({col} AS {data_type}) ELSE FALSE END AS {col}'
+    if retrieved_col_type == 'TEXT' and data_type == 'integer':
+        # To ensure we have a unified behavior between pandas, Snowflake & Postgres,
+        # additional logic is required to
+        # 1. replace any non-numeric valid string by ''
+        # 2. Keep the part between '.' (1 is equivalent to 0 in split part
+        # see https://docs.snowflake.com/en/sql-reference/functions/split_part.html#arguments)
+        # 3. Nullify the output if 1 or 2 results in empty strings i e non numeric value
+        # 4. Cast the resulting NULL or string representation of integer as Integer
+        return (
+            f'CAST(NULLIF(SPLIT_PART(REGEXP_REPLACE({col}, \'[^0-9.]*\', \'\'), \'.\', 1), \'\') '
+            f'AS {data_type}) AS {col}'
+        )
+    if retrieved_col_type == 'FLOAT' and data_type == 'integer':
+        return f'TRUNC({col}) AS {col}'
+
+    return f'CAST({col} AS {data_type}) AS {col}'
+
+
+def build_snowflake(retrieved_col_type, data_type, col):
+    if (retrieved_col_type == 'FLOAT' or retrieved_col_type == 'REAL') and data_type == 'integer':
+        return f'TRUNCATE({col}) AS {col}'
+    elif retrieved_col_type == 'TEXT' and data_type == 'integer':
+        return f"CAST(SPLIT_PART({col}, '.', 0) AS {data_type}) AS {col}"
+    elif (
+        retrieved_col_type == 'TIMESTAMP_NTZ' or retrieved_col_type == 'DATE'
+    ) and data_type == 'integer':
+        return f"CAST(DATE_PART('EPOCH_MILLISECOND', TO_TIMESTAMP({col})) AS {data_type}) AS {col}"
+    return f'CAST({col} AS {data_type}) AS {col}'
+
 
 def translate_convert(
     step: ConvertStep,
@@ -37,25 +77,18 @@ def translate_convert(
         f'query.metadata_manager.query_metadata: {query.metadata_manager.retrieve_query_metadata()}\n'
     )
 
+    is_postgres = sql_dialect == 'postgres'
+
     to_cast = []
     for col in step.columns:
         retrieved_col_type = query.metadata_manager.retrieve_query_metadata_column_type_by_name(
             column_name=col
         )
-        if (
-            retrieved_col_type == 'FLOAT' or retrieved_col_type == 'REAL'
-        ) and step.data_type == 'integer':
-            to_cast.append(f'TRUNCATE({col}) AS {col}')
-        elif retrieved_col_type == 'TEXT' and step.data_type == 'integer':
-            to_cast.append(f"CAST(SPLIT_PART({col}, '.', 0) AS {step.data_type}) AS {col}")
-        elif (
-            retrieved_col_type == 'TIMESTAMP_NTZ' or retrieved_col_type == 'DATE'
-        ) and step.data_type == 'integer':
-            to_cast.append(
-                f"CAST(DATE_PART('EPOCH_MILLISECOND', TO_TIMESTAMP({col})) AS {step.data_type}) AS {col}"
-            )
+
+        if is_postgres:
+            to_cast.append(build_psql(retrieved_col_type, step.data_type, col))
         else:
-            to_cast.append(f'CAST({col} AS {step.data_type}) AS {col}')
+            to_cast.append(build_snowflake(retrieved_col_type, step.data_type, col))
 
     for c in step.columns:
         query.metadata_manager.update_query_metadata_column_type(c, step.data_type)
